@@ -5,15 +5,19 @@ int main(int argc, char *argv[])
     MCAgency_t agency;
     MCAgencyOptions_t options;
     int i;
+    int port = 5051;
+    int remote_port = 5052;
     MC_InitializeAgencyOptions(&options);
-    /* We want _all_ the threads on: EXCEPT, the command prompt thread */
+
     for (i = 0; i < MC_THREAD_ALL; i++) {
         MC_SetThreadOn(&options, i);
     }
+    /* If the following line is uncommented, the command prompt will
+     * be turned off. */
  /*   MC_SetThreadOff(&options, MC_THREAD_CP);  */
 
     agency = MC_Initialize(
-            5051,
+            port,
             &options);
 
     /* Set up a condition variable */
@@ -27,7 +31,7 @@ int main(int argc, char *argv[])
           agency,
           "retrieval_agent.xml",
           "localhost",
-          5052
+          remote_port
           );
       MC_CondReset(agency, 42);
     }
