@@ -12,7 +12,7 @@ int main(int argc, char *argv[])
     MCAgency_t agency;
     MCAgencyOptions_t options;
     int i;
-    int port;
+    int port = 5051;
     MC_InitializeAgencyOptions(&options);
     /* We want _all_ the threads on: EXCEPT, the command prompt thread */
     for (i = 0; i < MC_THREAD_ALL; i++) {
