@@ -6,7 +6,6 @@ using System.Data;
 using System.Drawing;
 using System.Text;
 using System.Windows.Forms;
-using System.Runtime.InteropServices;
 using LibMC;
 
 /** \file /LibMCGui/Form1.cs
@@ -31,8 +30,6 @@ namespace LibMCTest
      */
     public partial class Form1 : Form
     {
-        public delegate int WriteDelegate(String s);
-
         private MCAgency Agency = new MCAgency();
         private static int localport = 5051;
         private static int remoteport = 5050;
@@ -60,13 +57,6 @@ namespace LibMCTest
         private void Form1_Load(object sender, EventArgs e)
         {
             label3.Text = Agency.State.ToString();
-
-            richTextBox1.AppendText("get_inc_int(): " + get_inc_int().ToString() + "\n");
-            
-            WriteDelegate d = new WriteDelegate(WriteLine);
-            IntPtr f = Marshal.GetFunctionPointerForDelegate(d);
-            setCallback(f);
-            callFptr("This is C# calling back to itself.");
         }
 
         /** 
@@ -194,18 +184,5 @@ namespace LibMCTest
             }
             label3.Text = Agency.State.ToString();
         }
-
-        public static int WriteLine(String s)
-        {
-            Console.WriteLine(s);
-            return 123;
-        }
-
-        [DllImport("C:\\Ch\\toolkit\\embedch\\package\\student\\dl\\libstudent.dl")]
-        public static extern int get_inc_int();
-        [DllImport("C:\\Ch\\toolkit\\embedch\\package\\student\\dl\\libstudent.dl")]
-        public static extern void setCallback(IntPtr f);
-        [DllImport("C:\\Ch\\toolkit\\embedch\\package\\student\\dl\\libstudent.dl")]
-        public static extern void callFptr(String s);
     }
 }
\ No newline at end of file
