@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -42,10 +42,12 @@
 #include <sys/time.h>
 #include <netdb.h>
 #include <pthread.h>
+#include "config.h"
 #else
 #include <winsock.h>
 #include <windows.h>
 #include <time.h>
+#include "winconfig.h"
 #endif
 
 #include <stdlib.h>
@@ -120,7 +122,7 @@ acc_MessageHandlerThread(LPVOID arg)
     {
       MUTEX_UNLOCK(mc_platform->quit_lock);
       MUTEX_UNLOCK(mc_platform->message_queue->lock);
-      return 0;
+      THREAD_EXIT();
     }
 
     MUTEX_UNLOCK(mc_platform->quit_lock);
@@ -232,50 +234,6 @@ acc_MessageHandlerThread(LPVOID arg)
           COND_BROADCAST(mc_platform->ams->runflag_cond);
           MUTEX_UNLOCK(mc_platform->ams->runflag_lock);
           break;
-          /* MC_SECURITY */
-#ifdef MC_SECURITY
-        case ENCRYPTED_DATA:
-          if (mc_platform->enable_security) {
-            message_queue_Add
-              (
-               mc_platform->asm_message_queue,
-               message
-              );
-          } else {
-            WARN("mc_security not enabled. Discarding ENCRYPTED_DATA message.");
-            message_Destroy(message);
-          }
-          break;
-        case ENCRYPTION_INITIALIZE: 
-          if (mc_platform->enable_security) {
-            asm_queue_Add
-              (
-               mc_platform->asm_queue,
-               asm_node_Initialize(message, mc_platform->security_manager)
-              );
-            /* Manually wake up the asm thread */
-            MUTEX_LOCK(mc_platform->asm_message_queue->lock);
-            COND_SIGNAL(mc_platform->asm_message_queue->cond);
-            MUTEX_UNLOCK(mc_platform->asm_message_queue->lock);
-            message_Destroy(message);
-          } else {
-            WARN("mc_security not enabled. Discarding ENCRYPTION_INITIALIZE message.");
-            message_Destroy(message);
-          }
-          break;
-        case REQUEST_ENCRYPTION_INITIALIZE:
-          if (mc_platform->enable_security) {
-            asm_SendEncryptionData(
-                mc_platform->security_manager,
-                message->from_address
-                );
-            message_Destroy(message);
-          } else {
-            WARN("mc_security not enabled. Discarding REQUEST_ENCRYPTION_INITIALIZE message.");
-            message_Destroy(message);
-          }
-          break;
-#endif /* END MC_SECURITY */
         case RELAY:
         case REQUEST:
         case SUBSCRIBE:
@@ -294,26 +252,9 @@ acc_MessageHandlerThread(LPVOID arg)
           message_Destroy(message);
       }
     } else {
-#ifdef MC_SECURITY
-      if (mc_platform->enable_security) {
-        if (
-            (message->message_type != ENCRYPTED_DATA) &&
-            (message->message_type != ENCRYPTION_INITIALIZE) &&
-            (message->message_type != REQUEST_ENCRYPTION_INITIALIZE)
-           )
-        {
-          message_queue_Add
-            (
-             mc_platform->asm_message_queue,
-             message
-            );
-          continue;
-        }
-      }
-#endif
       message_Send
         (
-         message
+         mc_platform, message, mc_platform -> private_key 
         );
       message_Destroy
         (
@@ -321,7 +262,7 @@ acc_MessageHandlerThread(LPVOID arg)
         );
     }
   }
-  return 0;
+  THREAD_EXIT();
 }
 
 #ifndef _WIN32
@@ -366,7 +307,7 @@ acc_Thread( LPVOID arg )
       {
         MUTEX_UNLOCK(mc_platform->quit_lock);
         MUTEX_UNLOCK(mc_platform->connection_queue->lock);
-        return 0;
+        THREAD_EXIT();
       }
     MUTEX_UNLOCK(mc_platform->quit_lock);
     MUTEX_UNLOCK(mc_platform->connection_queue->lock);
@@ -389,7 +330,7 @@ acc_Thread( LPVOID arg )
     /* Continue with normal operation */
     connection = connection_queue_Pop(mc_platform->connection_queue);
     mtp_http = mtp_http_New();
-    if ( mtp_http_InitializeFromConnection(mtp_http, connection ) )
+	if ( mtp_http_InitializeFromConnection(mtp_http, connection, mc_platform->private_key ) )
     {
       connection_Destroy(connection);
       mtp_http_Destroy(mtp_http);
@@ -509,25 +450,6 @@ acc_Thread( LPVOID arg )
       case FIPA_ACL:
         message_queue_Add(mc_platform->message_queue, message);
         break;
-#ifdef MC_SECURITY
-      case ENCRYPTED_DATA:
-      case ENCRYPTION_INITIALIZE:
-        if (mc_platform->enable_security) {
-          message_queue_Add(mc_platform->asm_message_queue, message);
-        } else {
-          WARN("MC Security not enabled. Discarding message...");
-          message_Destroy(message);
-        }
-        break;
-      case REQUEST_ENCRYPTION_INITIALIZE:
-        if (mc_platform->enable_security) {
-          message_queue_Add(mc_platform->message_queue, message);
-        } else {
-          WARN("MC Security not enabled. Discarding message...");
-          message_Destroy(message);
-        }
-        break;
-#endif
       default:
         fprintf(stderr, "Unknown message type:%d. Rejecting message.%s:%d\n",
             message->message_type,
@@ -581,6 +503,44 @@ acc_Start(mc_platform_p mc_platform)
     );
 }
 
+int
+auth_conn_rece_key(int sockfd, char *peer_name, int *nonce, unsigned char *aes_key, char *privkey, char* known_host_filename){
+	int ret = -1;
+	//char passphrase[35];
+	char privatekey[1210]; 
+	char peer_pubkey[300];
+	char plaintext[135];
+	
+	//memset(passphrase, '\0', 35);
+	memset(privatekey, '\0', 1210);
+	//memset(peer_pubkey,'\0', 300);
+	memset(plaintext,  '\0', 135);
+	memset(aes_key, '\0', 35);
+
+	strcpy(privatekey, privkey);
+	//printf("Authenticating %s \n", peer_name);
+	
+  /* Known host file lookup for peer public key */  
+  if (read_known_host_file(peer_pubkey, peer_name, known_host_filename) == -1 ){
+     printf("Server: %s 's Public key not found in known host file\n",peer_name);
+
+  }else{     
+     if ( (ret=reply_migration_process(sockfd, nonce, peer_pubkey, privatekey, aes_key)) != 1){
+        if (ret == -1)
+            printf("Server: Connected peer is not authenticated \n");
+        if (ret == -2)
+            printf("Server: Unable to get authentication from other peer \n");
+	 }else{ 
+		 if(ret == 2)
+		     ret = 2; // incase of Acl message in unencrypted form
+		 else
+		     ret = 1;		
+      }
+  }
+ return ret;
+}
+
+
 #ifndef _WIN32
   void*
 listen_Thread(void* arg)
@@ -599,8 +559,16 @@ listen_Thread( LPVOID arg )
   SOCKET sockfd;
   struct sockaddr_in sktin;
   struct sockaddr_in peer_addr;
+  struct sockaddr_in name_addr;  
+
+  struct hostent *remoteHost;
+    struct in_addr addr;
+
 #endif
 
+    unsigned char aes_key[35];
+  int nonce, ret;
+  char peer_name[45];	
   connection_p connection;
   u_long connection_number;
   int connectionlen;
@@ -647,38 +615,64 @@ listen_Thread( LPVOID arg )
         fprintf(stderr, "ListenThread: accept error \n");
 #ifdef _WIN32
         printf("Error number: %d\n", WSAGetLastError() );
-        continue;
 #endif
         continue;
       }
       else 
       {
-        /* Set waiting flag */
-        MUTEX_LOCK(mc_platform->acc->waiting_lock);
-        mc_platform->acc->waiting = 0;
-        COND_BROADCAST(mc_platform->acc->waiting_cond);
-        MUTEX_UNLOCK(mc_platform->acc->waiting_lock);
-        /* create a new connection and insert it into the connection linked 
-         * list */
-        connection = (connection_p)malloc(sizeof(connection_t));
-        CHECK_NULL(connection, exit(0););
-        connection->connect_id = rand();
-        connection->remote_hostname = NULL;
-        connection->addr = peer_addr;
-        connection->serverfd = sockfd;
-        connection->clientfd = connectionsockfd;
+        /* Acquire host name of connected   */
+#ifndef _WIN32
+        getnameinfo(&peer_addr, sizeof(peer_addr),
+            peer_name, sizeof(peer_name), NULL, 0, 0);
+#else
+        addr.s_addr = inet_addr( inet_ntoa(peer_addr.sin_addr) );
+        if (addr.s_addr == INADDR_NONE) 
+          printf("The IPv4 address entered must be a legal address\n");
+        else
+          remoteHost = gethostbyaddr((char *) &addr, 4, AF_INET);
 
-        /* add the connection to list and increment the number of connections */
-        connection_queue_Add(mc_platform->connection_queue, connection);
+        memset(peer_name, '\0', 45 );
+        strcpy(peer_name, remoteHost->h_name);
+
+#endif
+        //printf("peer_name = %s \n", peer_name);
+
+#ifdef NEW_SECURITY
+        /* Authentication Process for Received Connection  */
+        ret = auth_conn_rece_key(connectionsockfd, peer_name, &nonce, aes_key, mc_platform->private_key, mc_platform->agency->known_host_filename);
+        if( ret == 2 || ret == 1){
+          //printf("Successfully Authenticate %s \n", peer_name);
+          // Adding connection in connection_queue 
+#endif /* NEW_SECURITY */
+          /* Set waiting flag */
+          MUTEX_LOCK(mc_platform->acc->waiting_lock);
+          mc_platform->acc->waiting = 0;
+          COND_BROADCAST(mc_platform->acc->waiting_cond);
+          MUTEX_UNLOCK(mc_platform->acc->waiting_lock);
+          /* create a new connection and insert it into the connection linked 
+           * list */
+          connection = (connection_p)malloc(sizeof(connection_t));
+          CHECK_NULL(connection, exit(0););
+          connection->connect_id = rand();
+          connection->remote_hostname = NULL;
+          connection->addr = peer_addr;
+          connection->serverfd = sockfd;
+          connection->clientfd = connectionsockfd;
+#ifdef NEW_SECURITY
+          connection->nonce = nonce;
+          connection->AES_key = aes_key;
+#endif /* NEW_SECURITY */
+
+          /* add the connection to list and increment the number of connections */
+          connection_queue_Add(mc_platform->connection_queue, connection);
+#ifdef NEW_SECURITY
+        }else{ 
+          printf("Unable to authenticate %s \n", peer_name);
+        }
+#endif /* NEW_SECURITY */
       }
   }
 
   /* Free the current thread */
-#ifndef _WIN32
-  pthread_exit(0);
-#else
-  ExitThread(0);
-#endif
-
-  return 0;
+  THREAD_EXIT();
 }
