@@ -1,6 +1,6 @@
  /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -34,6 +34,9 @@
 
 #ifndef _WIN32
 #include <unistd.h>
+#include "config.h"
+#else
+#include "winconfig.h"
 #endif
 
 #include <embedch.h>
@@ -174,8 +177,6 @@ agent_Copy(const agent_p agent)
   cp_agent->return_data = agent->return_data;
   /*agent_interp*/
   cp_agent->agent_interp = NULL;
-  /*agent_thread*/
-  cp_agent->agent_thread = NULL;
   /*run_lock*/
   cp_agent->run_lock = (MUTEX_T*)malloc(sizeof(MUTEX_T));
   MUTEX_INIT(cp_agent->run_lock);
@@ -252,7 +253,6 @@ agent_Initialize(
   agent->agent_pipe_active = 0;
 
   /* set the agent thread to null until activated */
-  agent->agent_thread = NULL;
   agent->agent_thread_id = 0;
 
   /* Set up an empty mailbox */
@@ -350,7 +350,6 @@ agent_Destroy(agent_p agent)
   }
   free(agent->lock);
   agent_datastate_Destroy(agent->datastate);
-  free(agent->agent_thread);
   free(agent->run_lock);
   agent_mailbox_Destroy(agent->mailbox);
   /* deallocate the agent */
@@ -385,15 +384,10 @@ agent_RunChScript(agent_p agent, mc_platform_p mc_platform)
 	  stack_size = mc_platform->stack_size[MC_THREAD_AGENT];
   }
 #endif
-  if(agent->agent_thread == NULL) 
-  {
-    agent->agent_thread = (THREAD_T *)malloc(sizeof(THREAD_T));
-  }
-
   agent->agent_status = MC_AGENT_ACTIVE;
   agent->mc_platform = mc_platform;
 
-  THREAD_CREATE(agent->agent_thread,
+  THREAD_CREATE(&agent->agent_thread,
       agent_RunChScriptThread,
       agent );
 
@@ -742,6 +736,11 @@ agent_RunChScriptThread(void* ChAgent)
       "int mc_HaltAgency(void);",
       (ChFuncdl_t)MC_HaltAgency_chdl
       );
+  Ch_DeclareFunc(
+      agent->agent_interp,
+      "int mc_MigrateAgent(void* agent, const char* hostname, int port);",
+      (ChFuncdl_t)MC_MigrateAgent_chdl
+      );
   Ch_DeclareFunc(
       agent->agent_interp,
       "int mc_MutexLock(int id);",
@@ -906,7 +905,6 @@ FIXME: This is silly
     ChShellArg[1] = NULL;
     MUTEX_LOCK(agent->run_lock);
     Ch_RunScript(agent->agent_interp, ChShellArg); 
-    MUTEX_UNLOCK(agent->run_lock);
 
     /*        if(Ch_CallFuncByName(((MCAgent_t)ChAgent)->agent_interp, "main", NULL))
               {
@@ -919,6 +917,7 @@ FIXME: This is silly
 #ifndef _WIN32
     free(temp_store_file);
 #endif
+    MUTEX_UNLOCK(agent->run_lock);
   }
 
   /* now add the data element returned from the Ch execution into the agent data structure */
@@ -992,9 +991,7 @@ FIXME: This is silly
     }
   }
 
-  /* close the task, indicating that it has been completed */
-  agent->datastate->
-    tasks[agent->datastate->task_progress]->task_completed = 1;
+  /* Increment task progress */
   agent->datastate->task_progress++;
 
   if (
