@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
@@ -33,6 +33,12 @@
  * to the extent permitted by applicable law.
 ]*/
 
+#ifndef _WIN32
+#include "config.h"
+#else
+#include "winconfig.h"
+#endif
+
 #include "include/interpreter_variable_data.h"
 #include "include/agent.h"
 
