@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -32,6 +32,12 @@
  * to the extent permitted by applicable law.
 ]*/
 
+#ifndef _WIN32
+#include "config.h"
+#else
+#include "winconfig.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -62,7 +68,6 @@ agent_task_Copy(agent_task_p task)
   agent_task_p cp_task;
   cp_task = (agent_task_p)malloc(sizeof(agent_task_t));
 
-  cp_task->task_completed = task->task_completed;
   cp_task->number_of_elements = task->number_of_elements;
   cp_task->size_of_element_array = task->size_of_element_array;
   cp_task->persistent = task->persistent;
