@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -31,6 +31,11 @@
  * This software is provided "as is" without express or implied warranty
  * to the extent permitted by applicable law.
 ]*/
+#ifndef _WIN32
+#include "config.h"
+#else
+#include "winconfig.h"
+#endif
 
 #include "include/ams.h"
 #include "include/agent.h"
@@ -130,6 +135,17 @@ ams_ManageAgentList(ams_p ams)
       MUTEX_UNLOCK(alist->lock);
       MUTEX_LOCK(current_agent->lock);
       current_agent->orphan = 0;
+      MUTEX_LOCK(global->quit_lock);
+      if ( global->quit && current_agent->agent_status != MC_WAIT_MESSGSEND) {
+        MUTEX_UNLOCK(global->quit_lock);
+        MUTEX_UNLOCK(current_agent->lock);
+        MC_TerminateAgent(current_agent);
+        /* If we can lock the agent's run lock, then it must not bu running. */
+        MUTEX_LOCK(current_agent->run_lock);
+        MUTEX_UNLOCK(current_agent->run_lock);
+        continue;
+      }
+      MUTEX_UNLOCK(global->quit_lock);
       switch(current_agent->agent_status)
       {
         case MC_WAIT_CH :
@@ -160,6 +176,13 @@ ams_ManageAgentList(ams_p ams)
             message_Destroy(message);
             message = NULL;
           } else {
+            /* Rename the agent: This is done so that if the agent is coming back here
+             * very quickly, the names will not conflict. */
+            current_agent->name = realloc( 
+                current_agent->name, 
+                sizeof(char) * (strlen(current_agent->name) + 10)
+                );
+            strcat(current_agent->name, "_SENDING");
             message_queue_Add(
                 ams->mc_platform->message_queue,
                 message
@@ -258,12 +281,13 @@ ams_Thread( LPVOID arg )
     if (ams->run == 0 && mc_platform->quit) {
       MUTEX_UNLOCK(mc_platform->quit_lock);
       MUTEX_UNLOCK(ams->runflag_lock);
-      return 0;
+      ams_ManageAgentList(ams);
+      THREAD_EXIT();
     }
     ams->run = 0;
     MUTEX_UNLOCK(mc_platform->quit_lock);
     MUTEX_UNLOCK(ams->runflag_lock);
     ams_ManageAgentList(ams);
   }
-  return NULL;
+  THREAD_EXIT();
 }
