@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -37,8 +37,10 @@
 #include <stdio.h>
 #ifndef _WIN32
 #include <unistd.h>
+#include "config.h"
 #else
 #include <windows.h>
+#include "winconfig.h"
 #endif
 #include <stdlib.h>
 #include <string.h>
@@ -245,8 +247,10 @@ int dealloc_command(command_t *cmd) /*{{{*/
    * * * * * * * * * * * * * * */
 int handler_QUIT(void *arg, mc_platform_p global) /*{{{*/
 {
-    mc_platform_Destroy(global);
-    exit(0);
+    MUTEX_LOCK(global->quit_lock);
+    global->quit = 1;
+    COND_BROADCAST (global->quit_cond);
+    MUTEX_UNLOCK(global->quit_lock);
     return 0;
 } /*}}}*/
 
