@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -38,6 +38,9 @@
 #include <stdlib.h>
 #ifndef _WIN32
 #include <unistd.h>
+#include "config.h"
+#else
+#include "winconfig.h"
 #endif
 #include "include/mc_platform.h"
 #include "include/df.h"
@@ -461,7 +464,7 @@ DWORD WINAPI df_Thread( LPVOID arg )
       ) {
         MUTEX_UNLOCK(global->quit_lock);
         MUTEX_UNLOCK(global->df->request_list->lock);
-        return 0;
+        THREAD_EXIT();
       }
     MUTEX_UNLOCK(global->quit_lock);
     MUTEX_UNLOCK(global->df->request_list->lock);
