@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -83,7 +83,7 @@ struct agent_s {
 #else
   DWORD agent_thread_id;
 #endif
-  THREAD_T *agent_thread;
+  THREAD_T agent_thread;
 
   /* Agent Mailbox */
   agent_mailbox_p mailbox;
