@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -47,6 +47,8 @@ typedef struct connection_s {
 
   /* the primary id of the connection */
   int connect_id;
+  /* session identifier */
+  int nonce;
 
   /* socket - Network Variables */
   char *remote_hostname;
@@ -56,6 +58,10 @@ typedef struct connection_s {
   /* file descriptors */ 
   u_long clientfd;
   u_long serverfd;
+
+  /* connection key  */
+  unsigned char *AES_key;
+  
 }connection_t;
 typedef connection_t* connection_p;
 
