@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -224,6 +224,9 @@ typedef struct agency_s {
     int threads;                        /*!< flag which determines which threads to start */
     int enable_security;                /*!< Security flag */
     int stack_size[MC_THREAD_ALL];
+
+		char* priv_key_filename;
+		char* known_host_filename;
     error_code_t last_error;
 } agency_t;
 typedef agency_t* agency_p;
@@ -237,9 +240,13 @@ typedef struct MCAgencyOptions_s{
     int default_agent_status; /*!< Default agent status */
     int modified;             /*!< unused */
     int enable_security;      /*!< security enable flag */
+    unsigned char passphrase[32]; /*!< security enable flag */
 
     /* Following are some thread stack size options: unix/pthreads only! */
     int stack_size[MC_THREAD_ALL]; /*!< If the stack size is -1, use system def.*/
+
+		char *known_host_filename;
+		char *priv_key_filename;
 } MCAgencyOptions_t;
 
 #ifndef AGENT_T
@@ -428,6 +435,30 @@ MC_AgentVariableRetrieve(
     const char* var_name,
     int task_num);
 
+/**
+ * \brief           Retrieve a info about a previously saved variable.
+ *
+ * \param agent     A MobileC agent.
+ * \param var_name  The name of the saved variable that has previously
+ *                  been saved.
+ * \param task_num  The previous completed task from which to retrieve
+ *                  the saved variable.
+ * \param data      (Output) The Variable Data
+ * \param dim       (Output) The dimension of the data array
+ * \param extent    (Output) The extents of the output array
+ *
+ * \return          Error code.
+ */
+int
+MC_AgentVariableRetrieveInfo(
+    MCAgent_t agent,
+    const char* var_name,
+    int task_num,
+    const void** data,
+    int* dim,
+    const int** extent
+    );
+
 /**
  * \brief           Mark an agent variable for saving
  *
@@ -845,6 +876,17 @@ EXPORTMC extern int MC_InitializeAgencyOptions(struct MCAgencyOptions_s* options
  */
 EXPORTMC extern int MC_LoadAgentFromFile(MCAgency_t attr, const char* filename);
 
+/**
+ * \brief           Migrates a running agent to another host.
+ *
+ * \param agent     The agent to migrate
+ * \param hostname  The new host to migrate the agent to
+ * \param port      The new port to migrate the agent to
+ *
+ * \return          0 on success, error_code_t type on failure.
+ */
+EXPORTMC extern int MC_MigrateAgent(MCAgent_t agent, const char* hostname, int port);
+
 /**
  * \brief           Locks a MobileC synchronization variable as a mutex
  *
