@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -147,6 +147,9 @@ typedef name##_t* name##_p;
 #define THREAD_JOIN(thread_handle ) \
   pthread_join( thread_handle, NULL )
 
+#define THREAD_EXIT() \
+  pthread_exit(NULL)
+
 /* ***** */
 /* MUTEX */
 /* ***** */
@@ -319,6 +322,9 @@ pthread_cond_wait( queue->touched_signal, queue->thread_mutex )
 #define THREAD_JOIN(thread_handle) \
   WaitForSingleObject(thread_handle, INFINITE)
 
+#define THREAD_EXIT() \
+  ExitThread(0)
+
 /* ***** */
 /* MUTEX */
 /* ***** */
