@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -107,7 +107,11 @@ struct mc_platform_s{
   
   int quit;
   MUTEX_T *quit_lock;
+  COND_T *quit_cond;
   int sockfd; /* File Descriptor for listen socket */
+  char private_key[1210]; // private key of agency
+
+  MCAgency_t agency; /* A pointer to the platform's agency structure */
 };
 typedef struct mc_platform_s mc_platform_t;
 typedef mc_platform_t* mc_platform_p;
