@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -189,7 +189,7 @@ mtp_http_Destroy(mtp_http_p http);
 
 struct connection_s;
 int
-mtp_http_InitializeFromConnection(struct mtp_http_s *http, struct connection_s *connection);
+mtp_http_InitializeFromConnection(struct mtp_http_s *http, struct connection_s *connection, char *privatekey);
 
 mtp_http_p 
 mtp_http_New(void);
