@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -31,12 +31,18 @@
  * This software is provided "as is" without express or implied warranty
  * to the extent permitted by applicable law.
 ]*/
+#ifndef _WIN32
+#include "config.h"
+#else
+#include "winconfig.h"
+#endif
 
 #ifndef _WIN32
 #include <unistd.h>
 #include <pthread.h>
 #else
 #include <windows.h>
+#include <memory.h>
 #endif
 #include <embedch.h>
 
@@ -175,7 +181,9 @@ MC_AclSend(MCAgency_t attr, fipa_acl_message_t* acl)
 
       message_Send
         (
-         mc_message
+				 attr->mc_platform,
+         mc_message,
+				 attr->mc_platform->private_key
         );
       message_Destroy(mc_message);
       mtp_http_Destroy(msg);
@@ -345,6 +353,27 @@ const void* MC_AgentVariableRetrieve(MCAgent_t agent, const char* var_name, int
   return interp_var->data;
 }
 
+int MC_AgentVariableRetrieveInfo(MCAgent_t agent, const char* var_name, int task_num, const void** data, int* dim, const int** extent)
+{
+  interpreter_variable_data_t* interp_var;
+
+  if (task_num >= agent->datastate->task_progress) {
+    return MC_ERR_NOT_FOUND;
+  }
+
+  interp_var = agent_variable_list_Search(
+      agent->datastate->tasks[task_num]->agent_variable_list,
+      var_name );
+  if (interp_var == NULL) {
+    return MC_ERR_NOT_FOUND;
+  }
+  *data = interp_var->data;
+  *dim = interp_var->array_dim;
+  *extent = interp_var->array_extent;
+
+  return MC_SUCCESS;
+}
+
 int MC_AgentVariableSave(MCAgent_t agent, const char* var_name)
 {
   int current_task = agent->datastate->task_progress;
@@ -728,42 +757,51 @@ MC_End(MCAgency_t agency) /*{{{*/
    * to be done with whatever they are doing before exiting. */
   MUTEX_LOCK(agency->mc_platform->quit_lock);
   agency->mc_platform->quit = 1;
+  COND_BROADCAST( agency->mc_platform->quit_cond );
   MUTEX_UNLOCK(agency->mc_platform->quit_lock);
 
-  /* Stop the command prompt */
-  if( GET_THREAD_MODE( agency->threads, MC_THREAD_CP)) {
-    THREAD_CANCEL( agency->mc_platform->cmd_prompt->thread );
-  }
-
   /* Stop the listen thread */
   if( GET_THREAD_MODE( agency->threads, MC_THREAD_ACC)) {
     THREAD_CANCEL( agency->mc_platform->acc->listen_thread );
-  }
+  } 
 
   /* Stop the connection queue */
+  MUTEX_LOCK(agency->mc_platform->connection_queue->lock);
   COND_SIGNAL(agency->mc_platform->connection_queue->cond);
+  MUTEX_UNLOCK(agency->mc_platform->connection_queue->lock);
   if( GET_THREAD_MODE( agency->threads, MC_THREAD_ACC)) {
     THREAD_JOIN(agency->mc_platform->acc->thread);
   }
 
-  /* Stop the message queue */
-  COND_SIGNAL(agency->mc_platform->message_queue->cond);
-  if( GET_THREAD_MODE( agency->threads, MC_THREAD_ACC)) {
-    THREAD_JOIN(agency->mc_platform->acc->message_handler_thread);
-  }
-
   /* Stop the AMS */
+  MUTEX_LOCK(agency->mc_platform->ams->runflag_lock);
   COND_SIGNAL(agency->mc_platform->ams->runflag_cond);
+  MUTEX_UNLOCK(agency->mc_platform->ams->runflag_lock);
   if( GET_THREAD_MODE( agency->threads, MC_THREAD_AMS)) {
     THREAD_JOIN(agency->mc_platform->ams->thread);
   }
 
+  /* Stop the message queue */
+  MUTEX_LOCK(agency->mc_platform->message_queue->lock);
+  COND_SIGNAL(agency->mc_platform->message_queue->cond);
+  MUTEX_UNLOCK(agency->mc_platform->message_queue->lock);
+  if( GET_THREAD_MODE( agency->threads, MC_THREAD_ACC)) {
+    THREAD_JOIN(agency->mc_platform->acc->message_handler_thread);
+  }
+
   /* Stop the DF */
+  MUTEX_LOCK(agency->mc_platform->df->request_list->lock);
   COND_SIGNAL(agency->mc_platform->df->request_list->cond);
+  MUTEX_UNLOCK(agency->mc_platform->df->request_list->lock);
   if( GET_THREAD_MODE( agency->threads, MC_THREAD_DF)) {
     THREAD_JOIN(agency->mc_platform->df->thread);
   }
 
+  /* Stop the command prompt */
+  if( GET_THREAD_MODE( agency->threads, MC_THREAD_CP)) {
+    THREAD_CANCEL( agency->mc_platform->cmd_prompt->thread );
+  }
+
   mc_platform_Destroy(agency->mc_platform);
 
   if (agency->hostName)
@@ -1004,6 +1042,11 @@ MC_Initialize( /*{{{*/
   MCAgency_t ret;
   int i=0;
   int options_malloc = 0;
+  char privkey[1210];   // private key after decryption
+  FILE *f;
+  char buf[4], ch;
+
+  memset(privkey, '\0', 1210);
   ret = (MCAgency_t)malloc(sizeof(struct agency_s));
   if (ret == NULL) {return NULL;}
 
@@ -1020,9 +1063,6 @@ MC_Initialize( /*{{{*/
   ret->server = 1;
   ret->client = 0;
   ret->default_agentstatus = -1;
-#ifdef MC_SECURITY
-  ret->enable_security = 1;
-#endif
 
   /* Set up agency options */
   if(options==NULL) {
@@ -1032,9 +1072,6 @@ MC_Initialize( /*{{{*/
   }
   ret->threads = options->threads;
   ret->default_agentstatus = options->default_agent_status;
-#ifdef MC_SECURITY
-  ret->enable_security = options->enable_security;
-#endif
   for(i = 0; i < MC_THREAD_ALL; i++) {
     ret->stack_size[i] = options->stack_size[i];
   }
@@ -1042,12 +1079,67 @@ MC_Initialize( /*{{{*/
 
   ret->mc_platform = mc_platform_Initialize(ret);
 
+#ifdef NEW_SECURITY
+	if (options->priv_key_filename != NULL) {
+		ret->priv_key_filename = strdup(options->priv_key_filename);
+	} else {
+		ret->priv_key_filename = strdup("rsa_priv");
+	}
+	if (options->known_host_filename != NULL) {
+		ret->known_host_filename = strdup(options->known_host_filename);
+	} else {
+		ret->known_host_filename = strdup("known_host");
+	}
+  /* check whether private key file is encryt or not */
+ memset(buf,'\0', 4);
+
+  if( (f = fopen(ret->priv_key_filename, "r") ) == NULL) {
+    fprintf(stderr, "rsa_priv_en file not found \n");
+		fprintf(stderr, "Aborting... at %s:%d\n", __FILE__, __LINE__);
+		exit(0);
+	}
+
+  fread (buf, 1, 4, f);
+
+  if(buf[0]=='N' && buf[1] == ' ' && buf[2]=='=' && buf[3]==' '){
+    fread(privkey, 1210, 1, f);
+    fclose(f);
+  }
+  else{   
+    fclose(f);
+    /* prompt for passphrase if its NULL */ 
+    if(options->passphrase[0] == '\0'){
+      printf("Please enter the passphrase to decrypt private key  ");
+      scanf("%s", options->passphrase); 
+    }  
+    /* decrypting Private key */  
+    if( read_encrypted_file(ret->priv_key_filename, privkey, options->passphrase) == -1){
+      printf("Unable to read private key: passphase is wrong or file not exist\n");
+      printf("Press any key to exit \n");
+      getchar();
+      exit(0); 
+    }
+  }
+
+  if (privkey == NULL){
+     printf("Note: private key is Null \n");	
+	 printf("please verify the private key file or generate it again. \n");
+	 printf("Exiting Mobile-C Agency ... \n");
+	 getchar();
+	 exit(0);
+  }
+  memset(ret -> mc_platform -> private_key, '\0', 1210);
+  strcpy(ret -> mc_platform -> private_key, privkey);
+//  printf("My private key length =%d \n%s.\n",strlen(privkey), privkey);
+#endif /* NEW_SECURITY */
+
   /* Set up the global platform */
   g_mc_platform = ret->mc_platform;
 
   if (options_malloc)
     free(options);
 
+  ret->mc_platform->agency = ret;
   return ret;
 } /*}}}*/
 
@@ -1059,12 +1151,13 @@ MC_InitializeAgencyOptions(struct MCAgencyOptions_s* options) /*{{{*/
   options->threads = 0xFFFF;
   options->default_agent_status = MC_WAIT_CH;
   options->modified = 0;
-#ifdef MC_SECURITY
-  options->enable_security = 1;
-#endif
   for(i = 0; i < MC_THREAD_ALL; i++) {
     options->stack_size[i] = -1;
   }
+  memset(options->passphrase, '\0', 32);
+
+	options->known_host_filename = NULL;
+	options->priv_key_filename = NULL;
   return 0;
 } /*}}}*/
 
@@ -1138,6 +1231,28 @@ MC_LoadAgentFromFile(MCAgency_t attr, const char* filename)
   return 0;
 }
 
+EXPORTMC int
+MC_MigrateAgent(MCAgent_t agent, const char* hostname, int port)
+{
+  /* Rewrite the current task to be on "hostname" and "port" and
+   * resend the agent to its new destination */
+  int progress;
+  progress = agent->datastate->task_progress;
+  
+  /* Rewind the task progress */
+  agent->datastate->task_progress--;
+
+  /* Set the new servername */
+  free(agent->datastate->tasks[progress]->server_name);
+  agent->datastate->tasks[progress]->server_name = (char*)malloc(
+      sizeof(char)*(strlen(hostname) + 10) );
+  sprintf(agent->datastate->tasks[progress]->server_name, "%s:%d", 
+      hostname, port);
+
+  /* That is all. */
+  return 0;
+}
+
 EXPORTMC int 
 MC_MutexLock(MCAgency_t attr, int id) /*{{{*/
 {
@@ -1686,7 +1801,12 @@ MC_MainLoop(MCAgency_t attr) /*{{{*/
 int 
 MC_MainLoop(MCAgency_t attr) 
 {
-  return pthread_join(attr->mc_platform->ams->thread, NULL);
+  MUTEX_LOCK( attr->mc_platform->quit_lock );
+  while( attr->mc_platform->quit != 1 ) {
+    COND_WAIT( attr->mc_platform->quit_cond, attr->mc_platform->quit_lock );
+  }
+  MUTEX_UNLOCK( attr->mc_platform->quit_lock );
+  return 0;
 } /*}}}*/
 #endif
 
@@ -2532,6 +2652,24 @@ MC_HaltAgency_chdl(void *varg)
   return retval;
 }
 
+EXPORTCH int
+MC_MigrateAgent_chdl(void *varg)
+{
+  MCAgent_t agent;
+  const char* hostname;
+  int port;
+  int retval;
+  ChInterp_t interp;
+  ChVaList_t ap;
+
+  Ch_VaStart(interp, ap, varg);
+  agent = Ch_VaArg(interp, ap, MCAgent_t);
+  hostname = Ch_VaArg(interp, ap, const char*);
+  port = Ch_VaArg(interp, ap, int);
+  retval = MC_MigrateAgent(agent, hostname, port);
+  return retval;
+}
+
 /* MC_MutexLock_chdl */
 EXPORTCH int
 MC_MutexLock_chdl(void *varg) /*{{{*/
