@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -31,6 +31,11 @@
  * This software is provided "as is" without express or implied warranty
  * to the extent permitted by applicable law.
 ]*/
+#ifndef _WIN32
+#include "config.h"
+#else
+#include "winconfig.h"
+#endif
 
 #ifndef _WIN32
 #include <unistd.h>
@@ -61,9 +66,6 @@ mc_platform_Initialize(MCAgency_t agency)
 
   /* Initialize members */
   mc_platform->err = 0;
-#ifdef MC_SECURITY
-  mc_platform->enable_security = agency->enable_security;
-#endif
   mc_platform->default_agentstatus = agency->default_agentstatus;
 
   for(i = 0; i < MC_THREAD_ALL; i++) {
@@ -112,12 +114,6 @@ mc_platform_Initialize(MCAgency_t agency)
 
   mc_platform->interp_options = NULL;
 
-#ifdef MC_SECURITY
-  if (agency->enable_security) {
-    mc_platform->asm_message_queue = message_queue_New();
-    mc_platform->asm_queue         = asm_queue_New();
-  }
-#endif
   mc_platform->message_queue     = message_queue_New();
   mc_platform->agent_queue       = agent_queue_New();
   mc_platform->connection_queue  = connection_queue_New();
@@ -159,6 +155,8 @@ mc_platform_Initialize(MCAgency_t agency)
   mc_platform->quit = 0;
   mc_platform->quit_lock = (MUTEX_T*)malloc(sizeof(MUTEX_T));
   MUTEX_INIT(mc_platform->quit_lock);
+  mc_platform->quit_cond = (COND_T*)malloc(sizeof(COND_T));
+  COND_INIT(mc_platform->quit_cond);
 
   /* Initialize MC_signal flag */
   mc_platform->MC_signal = MC_NO_SIGNAL;
@@ -180,11 +178,6 @@ mc_platform_Initialize(MCAgency_t agency)
   mc_platform->ams        = ams_Initialize(mc_platform);
   mc_platform->acc        = acc_Initialize(mc_platform);
   mc_platform->cmd_prompt = cmd_prompt_Initialize(mc_platform);
-#ifdef MC_SECURITY
-  if (agency->enable_security) {
-    mc_platform->security_manager = asm_Initialize(mc_platform);
-  }
-#endif
   if (GET_THREAD_MODE(agency->threads, MC_THREAD_DF)) {
     df_Start(mc_platform);
     MUTEX_LOCK(mc_platform->df->waiting_lock);
@@ -214,31 +207,12 @@ mc_platform_Initialize(MCAgency_t agency)
   }
   if (GET_THREAD_MODE(agency->threads, MC_THREAD_CP))
     cmd_prompt_Start(mc_platform);
-#ifdef MC_SECURITY
-  if (agency->enable_security) {
-    asm_Start(mc_platform);
-    MUTEX_LOCK(mc_platform->security_manager->waiting_lock);
-    /* Wait for the thread to fully initialize before continuing */
-    while(mc_platform->security_manager->waiting == 0) {
-      COND_WAIT(
-          mc_platform->security_manager->waiting_cond,
-          mc_platform->security_manager->waiting_lock);
-    }
-    MUTEX_UNLOCK(mc_platform->security_manager->waiting_lock);
-  }
-#endif
-
   return mc_platform;
 }
 
 int
 mc_platform_Destroy(mc_platform_p platform)
 {
-#ifdef MC_SECURITY
-  if (platform->enable_security) {
-    message_queue_Destroy(platform->asm_message_queue);
-  }
-#endif
   /* Close the listen socket */
 #ifdef _WIN32
   closesocket(platform->sockfd);
@@ -252,18 +226,10 @@ mc_platform_Destroy(mc_platform_p platform)
 
   connection_queue_Destroy(platform->connection_queue);
 
-#ifdef MC_SECURITY
-  asm_queue_Destroy(platform->asm_queue);
-#endif
-
   df_Destroy(platform->df);
 
   ams_Destroy(platform->ams);
 
-#ifdef MC_SECURITY
-  asm_Destroy(platform->security_manager);
-#endif
-  
   acc_Destroy(platform->acc);
 
   cmd_prompt_Destroy(platform->cmd_prompt);
