@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -40,6 +40,7 @@
 #include <arpa/inet.h>
 #include <unistd.h>
 #include <netdb.h>
+#include "config.h"
 #else
 #include "winconfig.h"
 #endif
@@ -57,231 +58,6 @@
 
 #define SOCKET_INPUT_SIZE 4096
 
-#ifdef MC_SECURITY
-int message_Decrypt(message_p message, asm_node_p asm_node)
-{
-  int i;
-  mxml_node_t* message_node;
-  mxml_node_t* encrypted_data_node;
-  mxml_node_t* gaf_message_node;
-  char* encrypted_hex_string;
-  unsigned char* message_string;
-  char buf[3];
-  unsigned char iv[32];
-  int tmp = 0;
-  int decrypt_len;
-
-  gaf_message_node = mxmlFindElement
-    (
-     message->xml_root,
-     message->xml_root,
-     "MOBILEC_MESSAGE",
-     NULL,
-     NULL,
-     MXML_DESCEND
-    );
-  /* Find the message element */
-  message_node = mxmlFindElement
-    (
-     message->xml_root,
-     message->xml_root,
-     "MESSAGE",
-     NULL,
-     NULL,
-     MXML_DESCEND
-    );
-  if (message_node == NULL) return MC_ERR_PARSE;
-  encrypted_data_node = mxmlFindElement
-    (
-     message->xml_root,
-     message_node,
-     "ENCRYPTED_DATA",
-     NULL,
-     NULL,
-     MXML_DESCEND
-    );
-  if (encrypted_data_node == NULL) return MC_ERR_PARSE;
-  encrypted_hex_string = xml_get_text(encrypted_data_node);
-  
-  /* Now we need to convert the hex string into an unsigned char str. */
-  message_string = (unsigned char*)malloc
-    (
-     sizeof(char) * 
-     ((strlen(encrypted_hex_string)/2) + 32)
-    );
-  CHECK_NULL(message_string, exit(0););
-  buf[2] = '\0';
-  for(i = 0; i < (int)strlen(encrypted_hex_string); i += 2)
-  {
-    buf[0] = encrypted_hex_string[i];
-    buf[1] = encrypted_hex_string[i+1];
-    sscanf(buf, "%x", &tmp);
-    message_string[i/2] = (unsigned char) tmp; 
-  }
-
-  decrypt_len = 
-     strlen(encrypted_hex_string)/2;
-  memset(iv, 0, sizeof(iv));
-  aes_cbc_decrypt
-    (
-     &(asm_node->data.dh_data->aes),
-     iv,
-     (unsigned char*)message_string,
-     (unsigned char*)message_string,
-     decrypt_len
-    );
-  /* now we delete the old message node and compose a new one */
-  mxmlDelete(message_node);
-
-  mxmlLoadString
-    (
-     gaf_message_node,
-     (char*)message_string,
-     MXML_NO_CALLBACK
-    );
-
-  /* Free all stuff */
-  free(encrypted_hex_string);
-  free(message_string);
-
-  /* re-parse the message */
-  return message_xml_parse(message);
-}
-
-int
-message_Encrypt(message_p message, asm_node_p asm_node)
-{
-  int i;
-  int encrypt_len;
-  mxml_node_t* message_node;
-  mxml_node_t* gaf_message_node;
-  mxml_node_t* encrypted_data_node;
-  char* message_str;
-  int message_len;
-  char* encrypted_message_str;
-  unsigned char iv[32];
-  char buf[4];
-
-  /* First, check to see if the xml root exists. If not, we must create it */
-  if (message->xml_root == NULL) {
-    message->xml_root = mxmlLoadString
-      (
-       NULL,
-       message->message_body,
-       MXML_NO_CALLBACK
-      );
-  }
-
-  /* Now we can get rid of the old unencrypted message body */
-  if(message->message_body) {
-    free(message->message_body);
-    message->message_body = NULL;
-  }
-
-  message_node = mxmlFindElement
-    (
-     message->xml_root,
-     message->xml_root,
-     "MESSAGE",
-     NULL,
-     NULL,
-     MXML_DESCEND
-    );
-  if (message_node == NULL) {
-    return MC_ERR_PARSE;
-  }
-  message_str = mxmlSaveAllocString
-    (
-     message_node,
-     MXML_NO_CALLBACK
-    );
-  message_len = strlen(message_str);
-  message_str = realloc(message_str, message_len + 16);
-  CHECK_NULL(message_str, exit(0););
-
-  encrypt_len = message_len + (16 - message_len%16);
-  memset(iv, 0, sizeof(iv));
-  aes_cbc_encrypt
-    (
-     &(asm_node->data.dh_data->aes),
-     iv,
-     (unsigned char*) message_str,
-     (unsigned char*) message_str,
-     encrypt_len
-    );
-  encrypted_message_str = (char*) malloc
-    (
-     sizeof(char) * 
-     (encrypt_len*2)+1
-    );
-  CHECK_NULL(encrypted_message_str, exit(0););
-
-
-  encrypted_message_str[0] = '\0';
-  buf[2] = '\0';
-  for (i = 0; i < encrypt_len ; i++) 
-  {
-    sprintf(buf, "%02x", (unsigned char)message_str[i]);
-    strcat(encrypted_message_str, buf);
-  }
-
-  /* Now we delete the old message node and replace it with a new one */
-  mxmlDelete(message_node);
-  gaf_message_node = mxmlFindElement
-    (
-     message->xml_root,
-     message->xml_root,
-     "MOBILEC_MESSAGE",
-     NULL,
-     NULL,
-     MXML_DESCEND
-    );
-
-  message_node = mxmlNewElement
-    (
-     gaf_message_node,
-     "MESSAGE"
-    );
-  mxmlElementSetAttr
-    (
-     message_node,
-     "message",
-     "ENCRYPTED_DATA"
-    );
-  mxmlElementSetAttr
-    (
-     message_node,
-     "from",
-     message->from_address
-    );
-
-  encrypted_data_node = mxmlNewElement
-    (
-     message_node,
-     "ENCRYPTED_DATA"
-    );
-  
-  xml_new_cdata
-    (
-     encrypted_data_node,
-     encrypted_message_str
-    );
-
-  message->message_body = mxmlSaveAllocString
-    (
-     message->xml_root,
-     MXML_NO_CALLBACK
-    );
-
-  free(message_str);
-  free(encrypted_message_str);
-
-  message->message_type = ENCRYPTED_DATA;
-
-  return MC_SUCCESS;
-}
-#endif /*MC_SECURITY*/
-
 message_p
 message_New(void)
 {
@@ -651,12 +427,137 @@ message_Destroy(message_p message)
   return MC_SUCCESS;
 }
 
-  int
-message_Send(message_p message)
+// authenticating receiver and send message
+int
+auth_rece_send_msg(int sockfd, char *hostname, char *message, char *privkey, char *known_host_filename){
+
+  int ret=-1;
+  unsigned char passphrase[35], aes_key[35];
+  int nonce, mode;
+  char privatekey[1215];
+  char peer_pubkey[300], ch;
+  char plaintext[135];
+  FILE *fd, *tempfd;
+  char buffer[10];
+  struct stat stbuf;
+
+  /* temporary files  */
+  char *infile; //= "msg";     // message
+  char *outfile; //= "en-msg"; // encrypted message
+  char *tempfile;
+  memset(passphrase ,  '\0', 35);
+  memset(privatekey ,  '\0', 1215);
+  memset(plaintext  ,  '\0', 135);
+  memset(aes_key, '\0', 35);
+  //memset(infile, '\0', 20);
+  //memset(outfile, '\0', 20);
+  //memset(buffer, '\0', 10);
+
+#ifndef _WIN32   
+  int fd1;
+  infile = (char *)malloc(sizeof(char)*20);    
+  strcpy(infile, "msgXXXXXX");
+  fd1 = mkstemp(infile);
+  if (fd == -1) {
+     fprintf(stderr, "Could not create temporary file:%s. %s:%d\n",
+          infile, __FILE__, __LINE__ );
+     exit(EXIT_FAILURE);
+  } 
+  close(fd1);
+
+  outfile = (char *)malloc(sizeof(char)*20);
+  strcpy(outfile, "en-msgXXXXXX");
+  fd1 = mkstemp(outfile);
+  if (fd1 == -1) {
+     fprintf(stderr, "Could not create temporary file:%s. %s:%d\n",
+           outfile, __FILE__, __LINE__ );
+     exit(EXIT_FAILURE);
+  }
+  close(fd1);
+/*  
+  tempfile = (char *)malloc(sizeof(char)*20);
+  strcpy(tempfile, "tempXXXXXX");
+  fd1 = mkstemp(tempfile);
+  if(fd == -1){
+    printf("Could not create temporary file \n");
+    exit(EXIT_FAILURE);
+  }
+  close(fd1);
+*/
+#else
+  infile  = _tempnam(".", "msg");
+  outfile = _tempnam(".", "en-msg");
+#endif
+
+  /* srand(time(NULL));
+     num = rand();
+     sprintf(infile , "msg%d", num);
+     sprintf(outfile, "en-msg%d", num);
+  */     
+  strcpy(privatekey, privkey);
+  //printf("\n ################################### \n");	
+  //printf("Authenticating %s \n", hostname);	
+  //printf("Known host file lookup for peer public key ... \n");
+  // Known host file lookup for peer public key 
+  if (read_known_host_file(peer_pubkey, hostname, known_host_filename) == -1 ){
+     printf("Client: %s 's Public key not found in know host file\n", hostname);
+     if( remove(infile) ) printf("message.c : remove error 4");
+     if( remove(outfile) ) printf("message.c : remove error 5");
+#ifndef _WIN32
+       //close(sockfd);
+#else
+       //closesocket(sockfd);
+#endif
+  }else{
+       if ((ret=initiate_migration_process(sockfd, &nonce, peer_pubkey, privatekey, aes_key)) != 1){
+          if (ret == -1)
+             printf("Client: Connected peer is not authenticated \n");
+          if (ret == -2)
+             printf("Client: Unable to get authentication from oither peer \n");
+       }else{
+		//printf("Successfully Authenticate %s \n", hostname); 
+    		// printf("AES key is exchanged. \n");
+
+			// writing message (that is to be send) in a file.
+   		if( (fd = fopen(infile,"w")) == NULL){
+      		   printf("Unable to write message in a file \n");
+	           if( remove(infile) ) printf("message.c : remove error 1");
+      		}else{
+		     //printf("message length = %d \n", strlen(message) );	 
+      		     fwrite (message , 1 , strlen(message) , fd );
+                     fclose(fd);  
+                     // Encrypt message file
+                     mode = 0; // Encryption
+                     if (aes_en_de(mode, infile, outfile, aes_key, &nonce, 0) != 1){
+                         printf("Client: AES Encryption Failed \n");
+			 if( remove(infile) ) printf("message.c : remove error 2"); 
+	                 if( remove(outfile) ) printf("message.c : remove error 3");
+                 }else{	
+		      if( remove(infile) ) printf("message.c : remove error 4");
+                      if (send_AES_en_MA(sockfd, &nonce, outfile, peer_pubkey) != 1  ){
+                          printf("Client: Error while sending mobile agent \n");
+			  if( remove(outfile) ) printf("message.c : remove error 5");
+		      }else{
+			   if( remove(outfile) ) printf("message.c : remove error 6");
+                           //printf(" Successfully send the message \n");
+					       ret = 2;	
+					   }
+                  }
+             }
+        }
+   }
+  // printf("------------------------------ \n");  
+//  free(infile);
+//  free(outfile);
+//  free(tempfile);
+  return ret;
+}
+
+int message_Send(mc_platform_t* mc_platform, message_p message, char *privatekey)
 {
   char *buffer;
   mtp_http_t* mtp_http;
-  int n;
+  int n, ret;
 #ifndef _WIN32
   int skt;
   struct sockaddr_in sktin;
@@ -679,7 +580,7 @@ message_Send(message_p message)
         )
      )
   {
-     return MC_ERR;
+    return MC_ERR;
   }
 
   /* We need to split up the address into a hostname and port. */
@@ -717,11 +618,12 @@ message_Send(message_p message)
     free(buf);
     return MC_ERR_CONNECT;
   }
-  /* now send the string */
-  if(send(skt, message->message_body, strlen(message->message_body), 0) < 0) 
-  {
-    fprintf(stderr, "cannot write to socket %s:%d\n",
-        __FILE__, __LINE__);
+
+#ifdef NEW_SECURITY 
+  /*  authenticate the receiver of message */
+  ret = auth_rece_send_msg(skt, hostname, message->message_body, privatekey, mc_platform->agency->known_host_filename);
+  if( ret == 1  ){
+    printf("Successfull Authenticate and but send of MA is failed \n");
 #ifndef _WIN32
     close(skt);
 #else
@@ -729,37 +631,57 @@ message_Send(message_p message)
 #endif
     free(buf);
     return MC_ERR_SEND;
-  }
-  /* Now we should receive an HTTP response */
-  buffer = (char*) malloc(sizeof(char) * (SOCKET_INPUT_SIZE + 1));
-  CHECK_NULL(buffer, exit(0););
-  mtp_http = mtp_http_New();
+  }else if(ret != 2){
 #ifndef _WIN32
-  n = recvfrom(skt,
-      (void *) buffer,
-      (size_t) sizeof(char)*SOCKET_INPUT_SIZE,
-      0,
-      (struct sockaddr *) 0,
-      (socklen_t *) 0);
+    close(skt);
 #else
-  n = recvfrom(skt,
-      (void *) buffer,
-      (size_t) sizeof(char)*SOCKET_INPUT_SIZE,
-      0,
-      (struct sockaddr *) 0,
-      0);
+    closesocket(skt);
 #endif
-  if( mtp_http_Parse(mtp_http, buffer) ) {
-    fprintf(stderr, "http parsing error: Response expected. %s:%d\n",
-        __FILE__, __LINE__);
-    fprintf(stderr, "Received message was:\n%s\n", buffer);
-  }
-  if (mtp_http->response_code != 200) {
-    fprintf(stderr, "Warning: remote http server responded: %d %s\n",
-        mtp_http->response_code, mtp_http->response_string );
-  }
+    free(buf);
+    return MC_ERR_SEND;
+  }else if(ret == 2) // successfully authenticate and send
+    //printf("successfully authenticate and send \n");        
+#else
 
-  mtp_http_Destroy(mtp_http);
+    //printf("sending message body --\n%s\n--", message->message_body);	
+    if(send(skt, message->message_body, strlen(message->message_body), 0) < 0) {
+      perror(send);
+      printf("cannot write to socket %s:%d\n");
+    }
+    else
+#endif /* NEW_SECURITY */
+    {
+      // Now we should receive an HTTP response 
+      buffer = (char*) malloc(sizeof(char) * (SOCKET_INPUT_SIZE + 1));
+      CHECK_NULL(buffer, exit(0););
+      mtp_http = mtp_http_New();
+#ifndef _WIN32
+      n = recvfrom(skt,
+          (void *) buffer,
+          (size_t) sizeof(char)*SOCKET_INPUT_SIZE,
+          0,
+          (struct sockaddr *) 0,
+          (socklen_t *) 0);
+#else
+      n = recvfrom(skt,
+          (void *) buffer,
+          (size_t) sizeof(char)*SOCKET_INPUT_SIZE,
+          0,
+          (struct sockaddr *) 0,
+          0);
+#endif
+      if( mtp_http_Parse(mtp_http, buffer) ) {
+        fprintf(stderr, "http parsing error: Response expected. %s:%d\n",
+            __FILE__, __LINE__);
+        fprintf(stderr, "Received message was:\n%s\n", buffer);
+      }
+      if (mtp_http->response_code != 200) {
+        fprintf(stderr, "Warning: remote http server responded: %d %s\n",
+            mtp_http->response_code, mtp_http->response_string );
+      }
+
+      mtp_http_Destroy(mtp_http);
+    }
 
 #ifndef _WIN32
   close(skt);
