@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -31,6 +31,11 @@
  * This software is provided "as is" without express or implied warranty
  * to the extent permitted by applicable law.
 ]*/
+#ifndef _WIN32
+#include "config.h"
+#else
+#include "winconfig.h"
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -76,7 +81,7 @@ void message_queue_SendOutgoing(
     while ((message = (message_p)ListSearch(mqueue->list, index))) {
         MUTEX_UNLOCK(mqueue->lock);
         if (strcmp(message->to_address, local_address)) {
-            message_Send(message);
+            message_Send(mc_platform, message, mc_platform -> private_key);
             message_queue_RemoveIndex(mqueue, index);
             message_Destroy(message);
         } else {
