@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -93,11 +93,91 @@ mtp_http_New(void)
   return http;
 }
 
+int 
+rece_de_msg(char *buffer, connection_p con, char *privatekey){
+
+  FILE *fd, *tempfptr;
+  struct stat stbuf;
+  int mode,i,j;
+  /* temporary files */
+  char *infile;   // = "en-msg"; // encrypted message: 
+  char *outfile;  // = "msg";   // message
+  char ch;
+    
+#ifndef _WIN32   
+  int fd1;
+  infile = (char *)malloc(sizeof(char)*20);         
+  strcpy(infile, "en-msgXXXXXX");
+  fd1 = mkstemp(infile);
+  if (fd1 == -1) {
+     fprintf(stderr, "Could not create temporary file:%s. %s:%d\n",
+          infile, __FILE__, __LINE__ );
+     exit(EXIT_FAILURE);
+  }   
+  close(fd1);
+
+  outfile = (char *)malloc(sizeof(char)*20);
+  strcpy(outfile, "enXXXXXX");
+  fd1 = mkstemp(outfile);
+  if (fd1 == -1) {
+     fprintf(stderr, "Could not create temporary file:%s. %s:%d\n",
+	outfile, __FILE__, __LINE__ );
+     exit(EXIT_FAILURE);
+  }
+  close(fd1);
+#else
+  infile  = _tempnam(".", "msg");
+  outfile = _tempnam(".", "en-msg");
+#endif
+
+  // Receive encrypted mesg and write in infile   
+  if (receive_AES_en_MA(con->clientfd, &(con->nonce), infile, privatekey ) != 1){
+     printf("Server: Fail to successfully encrypted msg \n");
+	 if( remove(infile) )  printf("mtp_http.c : remove error 1");
+     return -1;
+  }
+  
+  // decrypte infile using aes key and put plaintext content in outfile
+  mode = 1;  // Decryption mode
+  // decrypt infile and write plaintext in outfile
+  if (aes_en_de(mode, infile, outfile, con->AES_key, &(con->nonce), con->clientfd) != 1){
+     printf("Server: AES Decryption failed \n");	 
+     if( remove(infile) )  printf("mtp_http.c : remove error 2");
+     if( remove(outfile) ) printf("mtp_http.c : remove error 3");
+     return -1;
+  } 
+   
+  if( (fd = fopen(outfile,"r")) == NULL ){
+     printf("Cannot find %s file to read msg content", outfile);
+     if( remove(infile) )  printf("mtp_http.c : remove error 4");
+     if( remove(outfile) ) printf("mtp_http.c : remove error 5");
+     return -1;	
+  }
+  stat(outfile, &stbuf);  
+  // copy whole file into buffer
+  // read output file except carriage return
+  j=0;
+  for(i=0; i<(int)stbuf.st_size; i++ ){
+  //while( (ch = fgetc(fd)) != EOF ){
+       ch = fgetc(fd);
+       if(ch != '\r')
+           buffer[j++]=ch;
+       else
+           buffer[j++]=' ';
+  }
+
+  fclose(fd);
+  // after successfull getting mesg remove temporary files
+  if( remove(infile) )  printf("mtp_http.c : remove error 6");
+  if( remove(outfile) ) printf("mtp_http.c : remove error 7");
+  return strlen(buffer);
+}
 int
 mtp_http_InitializeFromConnection
 (
  mtp_http_p http,
- connection_p connection
+ connection_p connection,
+ char *privatekey
  )
 {
   int i=1;
@@ -112,24 +192,33 @@ mtp_http_InitializeFromConnection
   buffer = (char*) malloc(sizeof(char) * (SOCKET_INPUT_SIZE + 1));
   CHECK_NULL(buffer, exit(0););
   message_string = dynstring_New();
-  buffer[0] = '\0';
+  memset(buffer, '\0', (sizeof(char) * (SOCKET_INPUT_SIZE + 1)) );
 
   while(1){
-#ifndef _WIN32
-    n = recvfrom(connection->clientfd,
-        (void *) buffer,
-        (size_t) sizeof(char)*SOCKET_INPUT_SIZE,
-        0,
-        (struct sockaddr *) 0,
-        (socklen_t *) 0);
+#ifdef NEW_SECURITY
+    if ( (n = rece_de_msg(buffer, connection, privatekey)) == -1 ){
+   	  printf("Error on receving en msg \n");
+	  free(buffer);
+	  return 2;
+    }
 #else
-    n = recvfrom(connection->clientfd,
-        (void *) buffer,
-        (size_t) sizeof(char)*SOCKET_INPUT_SIZE,
-        0,
-        (struct sockaddr *) 0,
-        0);
-#endif
+	#ifndef _WIN32
+	n = recvfrom(connection->clientfd,
+		(void *) buffer,
+		(size_t) sizeof(char)*SOCKET_INPUT_SIZE,
+		0,
+		(struct sockaddr *) 0,
+		(socklen_t *) 0);
+		//printf("recev message %s\n", buffer);	
+	#else
+	n = recvfrom(connection->clientfd,
+		(void *) buffer,
+		(size_t) sizeof(char)*SOCKET_INPUT_SIZE,
+		0,
+		(struct sockaddr *) 0,
+		0);
+	#endif
+#endif /* NEW_SECURITY */
     received_len += n;
     if (n < 0) {
       free(buffer);
