@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -31,6 +31,11 @@
  * This software is provided "as is" without express or implied warranty
  * to the extent permitted by applicable law.
 ]*/
+#ifndef _WIN32
+#include "config.h"
+#else
+#include "winconfig.h"
+#endif
 
 #include <mxml.h>
 #include "include/agent.h"
@@ -332,14 +337,6 @@ agent_xml_compose__task(agent_p agent, int index)
       agent->datastate->tasks[index]->server_name
       );
 
-  /* Set up task completion attribute */
-  sprintf(buf, "%d", agent->datastate->tasks[index]->task_completed);
-  mxmlElementSetAttr(
-      node,
-      "complete",
-      buf
-      );
-
   /* Set up the code id */
   if (agent->datastate->tasks[index]->code_id) {
     mxmlElementSetAttr(
@@ -371,8 +368,6 @@ agent_xml_compose__task(agent_p agent, int index)
           "no-return",
           agent->datastate->tasks[index]->var_name
           )
-        &&
-        agent->datastate->tasks[index]->task_completed
       )
     {
 
@@ -383,15 +378,13 @@ agent_xml_compose__task(agent_p agent, int index)
             agent->datastate->tasks[index]->agent_return_data);
       } else {tmp_node = NULL;}
 
-      if(tmp_node == NULL) {
-        fprintf(stderr, "Compose error. %s:%d\n", __FILE__, __LINE__);
-        return NULL;
+      if(tmp_node != NULL) {
+        mxmlAdd(
+            node,
+            MXML_ADD_AFTER,
+            NULL,
+            tmp_node );
       }
-      mxmlAdd(
-          node,
-          MXML_ADD_AFTER,
-          NULL,
-          tmp_node );
     }
   }
 
