@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 261 $ : Last Committed Revision
- * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
+ * $Revision: 319 $ : Last Committed Revision
+ * $Date: 2009-04-29 17:04:14 -0700 (Wed, 29 Apr 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -465,15 +465,6 @@ agent_xml_parse__task(agent_p agent, xml_parser_p xml_parser, int index)
       );
   CHECK_NULL(attribute, return MC_ERR_PARSE;);
 
-  /* 'complete' - Is this task complete?*/
-  attribute = mxmlElementGetAttr(
-      (mxml_node_t*)task_node,
-      "complete"
-      );
-  CHECK_NULL(attribute, return MC_ERR_PARSE;);
-  agent->datastate->tasks[index]->task_completed = 
-    atoi((char*)attribute);
-  
   /* 'server' - The server this task should be performed on */
   attribute = mxmlElementGetAttr(
       (mxml_node_t*)task_node,
@@ -697,6 +688,9 @@ agent_xml_parse__row(interpreter_variable_data_t* interp_variable, xml_parser_p
        interp_variable->data_type,
        data_type_size
       );
+    if (interp_variable->data_type == CH_CHARTYPE) {
+      num_elements++;
+    }
     interp_variable->data =
       malloc(num_elements * data_type_size);
 
@@ -750,8 +744,10 @@ void agent_xml_parse__fill_row_data(
     while ( tmp != NULL) {
       switch(type) {
         case CH_CHARTYPE:
-          if (data != NULL)
+          if (data != NULL) {
             ((char*)data)[*index] = *(char*)tmp;
+            ((char*)data)[*index+1] = '\0';
+          }
           (*index)++;
           break;
         case CH_INTTYPE:
